src/cx/allocator.h

changeset 1188
b0300de92b72
parent 1185
d825aca193d3
parent 1169
6a33a5648027
--- a/src/cx/allocator.h	Tue Feb 11 19:51:02 2025 +0100
+++ b/src/cx/allocator.h	Tue Feb 11 19:55:32 2025 +0100
@@ -65,8 +65,8 @@
      */
     void *(*calloc)(
             void *data,
-            size_t nelem,
-            size_t n
+            size_t nmemb,
+            size_t size
     );
 
     /**
@@ -395,11 +395,11 @@
         cxReallocateArray_(allocator, (void**) (mem), nmemb, size)
 
 /**
  * Allocate @p nelem elements of @p n bytes each, all initialized to zero.
  *
  * @param allocator the allocator
  * @param nelem the number of elements
  * @param n the size of each element in bytes
  * @return a pointer to the allocated memory
  */
 cx_attr_nonnull_arg(1)
@@ -410,8 +410,8 @@
 cx_attr_export
 void *cxCalloc(
         const CxAllocator *allocator,
-        size_t nelem,
-        size_t n
+        size_t nmemb,
+        size_t size
 );
 
 #ifdef __cplusplus
@@ -395,11 +395,11 @@
 
 /**
- * Allocate @p nelem elements of @p n bytes each, all initialized to zero.
+ * Allocate @p nmemb elements of @p n bytes each, all initialized to zero.
  *
  * @param allocator the allocator
@@ -395,11 +395,11 @@
  *
  * @param allocator the allocator
- * @param nelem the number of elements
- * @param n the size of each element in bytes
+ * @param nmemb the number of elements
+ * @param size the size of each element in bytes
  * @return a pointer to the allocated memory
  */

mercurial